==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: cs\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "Linka"

, "Caller Id"
: "ID volajícího"

, "Start"
: "Začátek"

, "Connected"
: "Spojený"

, "Disconnected"
: "Odpojený"

, "Duration"
: "Trvání"

, "Ringing"
: "Vyzvání"

, "Direction"
: "Směr"

, "Source"
: "Zdroj"

, "Destination"
: "Cíl"

, "Phone"
: ""

, "Phones"
: "Telefony"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "Číslo"

, "Cancel"
: "Zrušit"

, "Dial"
: "Vytočit"

, "Error"
: "Chyba"

, "Not possible to dial."
: "Nelze vytočit."

, "Edit phone settings"
: "Editovat nastavení telefonu"

, "Dial number"
: "Vytočit číslo"

, "Initiate a new outgoing call"
: "Zahájit nový odchozí hovor"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: ""

, "Work"
: ""

, "Home"
: ""

, "Cell"
: ""

, "Cell private"
: ""

, "Incoming call"
: "Příchozí hovor"

, "Outgoing call"
: "Odchozí hovor"

, "unknown number"
: "neznámé číslo"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.08.8.tar.bz2: Phone/js/Phone-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Příchozí hovor"

, "Outgoing call"
: "Odchozí hovor"

, "unknown number"
: "neznámé číslo"

, "Phone"
: ""

, "Line"
: "Linka"

, "Number"
: "Číslo"

, "Cancel"
: "Zrušit"

, "Dial"
: "Vytočit"

, "Error"
: "Chyba"

, "Not possible to dial."
: "Nelze vytočit."

, "Call contact"
: ""

, "Work"
: ""

, "Home"
: ""

, "Cell"
: ""

, "Cell private"
: ""

, "Edit phone settings"
: "Editovat nastavení telefonu"

, "Dial number"
: "Vytočit číslo"

, "Initiate a new outgoing call"
: "Zahájit nový odchozí hovor"

, "Phones"
: "Telefony"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "ID volajícího"

, "Start"
: "Začátek"

, "Connected"
: "Spojený"

, "Disconnected"
: "Odpojený"

, "Duration"
: "Trvání"

, "Ringing"
: "Vyzvání"

, "Direction"
: "Směr"

, "Source"
: "Zdroj"

, "Destination"
: "Cíl"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
